pub struct RemoteOptions { /* private fields */ }Expand description
Options for remote sources
media_buffer_len is how many bytes are to be buffered in totala
forward_buffer is how many bytes can ahead of the seek position without the remote source being read from